@@ -109,7 +109,6 @@ def install_single(p, dep = False):
 		if not p.installed():
 			print ['Installing: ', 'Installing dependency: '][int(dep)] + p.name
 			p.install(ProgressBar())
-			print
 		elif not dep:
 			print 'Already installed: ' + p.name
 
@@ -156,29 +155,33 @@ def list_packages(searchterm, available):
 	""" List all packages whose name matches searchterm."""
 	s = searchterm.lower()
 	print 'Installed packages:'
-	for p in [p for p in rapid.packages() if p.installed() and s in p.name.lower()]:
-		print '  %-40s (%s)' % (p.name, ', '.join(p.tags))
+	for p in rapid.packages():
+		if p.installed() and s in p.name.lower():
+			print '  %-40s (%s)' % (p.name, ', '.join(p.tags))
 	if available:
 		print 'Available packages:'
-		for p in [p for p in rapid.packages() if not p.installed() and s in p.name.lower()]:
-			print '  %-40s (%s)' % (p.name, ', '.join(p.tags))
+		for p in rapid.packages():
+			if not p.installed() and s in p.name.lower():
+				print '  %-40s (%s)' % (p.name, ', '.join(p.tags))
 
 
 def list_tags(searchterm, available):
 	""" List all tags which match searchterm."""
 	s = searchterm.lower()
 	print 'Pinned tags:'
-	for tag in filter(lambda t: s in t.lower(), rapid.pinned_tags()):
-		p = rapid.packages()[tag]
-		if p:
-			print '  %-40s (%s)' % (tag, p.name)
-		else:
-			print '  %-40s [dangling tag]' % tag
+	for tag in rapid.pinned_tags():
+		if s in tag.lower():
+			p = rapid.packages()[tag]
+			if p:
+				print '  %-40s (%s)' % (tag, p.name)
+			else:
+				print '  %-40s [dangling tag]' % tag
 	if available:
 		print 'Available tags:'
-		for tag in (set(rapid.tags()) - set(rapid.pinned_tags())):
-			p = rapid.packages()[tag]
-			print '  %-40s (%s)' % (tag, p.name)
+		for tag in rapid.tags():
+			if s in tag.lower() and s not in rapid.pinned_tags():
+				p = rapid.packages()[tag]
+				print '  %-40s (%s)' % (tag, p.name)
 
 
 def upgrade(searchterm):
@@ -192,16 +195,21 @@ def uninstall_unpinned():
 	    pinned tags. This does not touch pool files."""
 	# Build set marked_packages that should be kept.
 	marked_packages = set()
-	new_packages = set([rapid.packages()[t] for t in rapid.pinned_tags() if t in rapid.tags()])
+	new_packages = set(rapid.packages()[t] for t in rapid.pinned_tags() if t in rapid.tags())
 	while new_packages:
 		marked_packages.update(new_packages)
 		new_packages = sum([list(p.dependencies) for p in new_packages], [])
 
 	# Build set of packages that will be removed.
-	garbage = set(set([p for p in rapid.packages() if p.installed()]) - marked_packages)
+	garbage = set(set(p for p in rapid.packages() if p.installed()) - marked_packages)
+
+	# Anything to do?
+	if not garbage:
+		print 'Nothing to do.'
+		return
 
 	# Confirmation?
-	if (not raw_input('Uninstall %s? [y/N]: ' % ', '.join([p.name for p in garbage])).startswith('y')):
+	if (not raw_input('Uninstall %s? [y/N]: ' % ', '.join(p.name for p in garbage)).startswith('y')):
 		return
 
 	# Uninstall all garbage.
@@ -216,7 +224,7 @@ def collect_pool():
 	# Build set marked_files that should be kept.
 	installed_packages = [p for p in rapid.packages() if p.installed()]
 	marked_files = reduce(lambda x, y: x + y.get_files(), installed_packages, [])
-	marked_files = set([f.get_pool_path() for f in marked_files])
+	marked_files = set(f.get_pool_path() for f in marked_files)
 
 	def gc(really_remove):
 		# Remove all files not in marked_files.
@@ -269,7 +277,6 @@ def make_sdd(package, path):
 	if missing_files:
 		print 'Downloading %d missing files for: %s' % (len(missing_files), package.name)
 		package.download_files(missing_files, ProgressBar())
-		print
 
 	files = package.get_files()
 	print 'Extracting %d files into: %s' % (len(files), path)
@@ -282,7 +289,6 @@ def make_sdd(package, path):
 			with closing(open(target_name, 'wb')) as target:
 				target.write(source.read())
 		progress(1)
-	print
 
 
 where = [2]
